@@ -26,6 +26,8 @@ class NotificationStack(Stack):
         super().__init__(scope, construct_id, **kwargs)
 
         pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name) 
+        print(apns_certificate)
+        print(apns_private_key)
 
         cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
             application_id=pinpoint_app.ref,
@@ -33,7 +35,7 @@ class NotificationStack(Stack):
             # the properties below are optional
             bundle_id=apns_bundle_id,
             certificate=apns_certificate,
-            # default_authentication_method="certificate",
+            default_authentication_method="CERTIFICATE", 
             enabled=True,
             private_key=apns_private_key,
             # team_id="teamId",
